==> pycrypt-cli-0.4.tar.gz: pycrypt-cli-0.4/pycryptcli/techniques.py <==
#modules
import base64
import hashlib

#---<encryption>---#
class encryption:
	#cipher
	def ascii(string):
	    c = ""
	    for i in string:
	        c = c + str(ord(i))
	        c += " "
	    return c[:-1]

	def caeserCipher(string, key):
		key = int(key)
		c = ""
		for i in range (len(string)):
			a = string[i]
			if ord(a) not in range(65,91) and ord(a) not in range (97,124):
				c += a
			elif a.isupper():
				c += chr((ord(a) + key - 65) % 26 + 65)
			else:
				c += chr((ord(a) + key - 97) % 26 + 97)
		return c

	def vigenereCipher(string, key):
	    c = ""
	    a = [ord(i) for i in (string)]
	    b = [ord(j) for j in (key)]
	    for x in range (len(n)):
	        d = (a[x] + b[x % len(k)]) % 26
	        if d.islower():
	        	c = c + chr(65 + d)
	        else:
	        	c = c+ chr(97 + d)
	    return c

	def morseCode(string):
		code = {
			' ':'|',
			'a':'.-',
			'b':'-...',
			'c':'-.-.',
			'd':'-..',
			'e':'.',
			'f':'..-.',
			'g':'--.',
			'h':'....',
			'i':'..',
			'j':'.---',
			'k':'-.-',
			'l':'.-..',
			'm':'--',
			'n':'-.',
			'o':'---',
			'p':'.--.',
			'q':'--.-',
			'r':'.-.',
			's':'...',
			't':'-',
			'u':'..-',
			'v':'...-',
			'w':'.--',
			'x':'-..-',
			'y':'-.--',
			'z':'--..',
			'0':'-----',
			'1':'.----',
			'2':'..---',
			'3':'...--',
			'4':'....-',
			'5':'.....',
			'6':'-....',
			'7':'--...',
			'8':'---..',
			'9':'----.'
		}
		b = ""
		for i in string:
			if i.isalpha() == True:
				i = i.lower()
			if i in code:
				b += code[i]
			else:
				b += "#"
			b += " "
		return b[:-1]

	def tapCode(string):
		code = {
		    "A": ". .",
		    "B": ". ..",
		    "C": ". ...",
		    "D": ". ....",
		    "E": ". .....",
		    "F": ".. .",
		    "G": ".. ..",
		    "H": ".. ...",
		    "I": ".. ....",
		    "J": ".. .....",
		    "K": ". ...",
		    "L": "... .",
		    "M": "... ..",
		    "N": "... ...",
		    "O": "... ....",
		    "P": "... .....",
		    "Q": ".... .",
		    "R": ".... ..",
		    "S": ".... ...",
		    "T": ".... ....",
		    "U": ".... .....",
		    "V": "..... .",
		    "W": "..... ..",
		    "X": "..... ...",
		    "Y": "..... ....",
		    "Z": "..... .....",
		}
		c = ""
		string = string.upper()
		string = string.rstrip("\n")
		for i in string:
			if i in code:
				c += code[i] + "/"
			elif i == " ":
				c += " "
			else:
				c += "#"
		return c

	#numeric
	def binary(string):
		string = string.split(" ")
		ans = ""
		for i in string:
			if i.isdigit() == False:
				ans += bin(int(ord(i)))[2:]
			else:
				ans += bin(int(i))[2:]
		return ans

	def octal(string):
	    string = string.split(" ")
	    ans = ""
	    for i in string:
	    	if i.isdigit() == False:
	    		ans += oct(int(ord(i)))[2:]
	    	else:
	    		ans += oct(int(i))[2:]
	    return ans

	def hexadecimal(string):
		string = string.split(" ")
		ans = ""
		for i in string:
			if i.isdigit() == False:
				ans += hex(int(ord(i)))[2:]
			else:
				ans += hex(int(i))[2:]
		return ans

	#encoding
	def base16(string):
	    m = string.encode("ascii")
	    a = base64.b16encode(m)
	    c = a.decode("ascii")
	    return c

	def base32(string):
	    m = string.encode("ascii")
	    a = base64.b32encode(m)
	    c = a.decode("ascii")
	    return c

	def base64(string):
	    m = string.encode("ascii")
	    a = base64.b64encode(m)
	    c = a.decode("ascii")
	    return c

	def base85(string):
	    m = string.encode("ascii")
	    a = base64.b85encode(m)
	    c = a.decode("ascii")
	    return c

	#hash function
	def md5(string):
		n = string.encode()
		c = hashlib.md5(n).hexdigest()
		return c 

	def sha224(string):
		n = string.encode()
		c = hashlib.sha224(n).hexdigest()
		return c

	def sha256(string):
		n = string.encode()
		c = hashlib.sha256(n).hexdigest() 
		return c
	
	def sha384(string):
		n = string.encode()
		c = hashlib.sha384(n).hexdigest() 
		return c

	def sha512(string):
		n = string.encode()
		c = hashlib.sha512(n).hexdigest() 
		return c

	def sha3_256(string):
		n = string.encode()
		c = hashlib.sha3_256(n).hexdigest() 
		return c

	def sha3_512(string):
		n = string.encode()
		c = hashlib.sha3_512(n).hexdigest() 
		return c

	def blake2_256(string):
		n = string.encode()
		c = hashlib.blake2s(n).hexdigest() 
		return c

	def blake2_512(string):
		n = string.encode()
		c = hashlib.blake2b(n).hexdigest() 
		return c
#---</encryption>---#

#---<decryption>---#
class decryption:
	#cipher
	def ascii(string):
		n = string.split(" ")
		c = ""
		for i in n:
			c = c + str(chr(int(i)))
		return c

	def caeserCipher(string, key):
		key = int(key)
		c = ""
		for i in range (len(string)):
			a = string[i]
			if ord(a) not in range (65,91) and ord(a) not in range (97,124):
				c += a
			elif a.isupper():
				c += chr((ord(a) - key - 65) % 26 + 65)
			else:
				c += chr((ord(a) - key - 97) % 26 + 97)
		return c

	def vigenereCipher(string, key):
		c = ""
		a = [ord(i) for i in (string)]
		b = [ord(i) for j in (key)]
		for x in range (len(n)):
			d = (a[x] - b[x % len(key)]) % 26
			if d.islower():
				c += chr(65 + d)
			else:
				c += chr(97 + d)
		return c

	def morseCode(string):
		code={
			'|':' ',
			'.-':'a',
			'-...':'b',
			'-.-.':'c',
			'-..':'d',
			'.':'e',
			'..-.':'f',
			'--.':'g',
			'....':'h',
			'..':'i',
			'.---':'j',
			'-.-':'k',
			'.-..':'l',
			'--':'m',
			'-.':'n',
			'---':'o',
			'.--.':'p',
			'--.-':'q',
			'.-.':'r',
			'...':'s',
			'-':'t',
			'..-':'u',
			'...-':'v',
			'.--':'w',
			'-..-':'x',
			'-.--':'y',
			'--..':'z',
			'-----':'0',
			'.----':'1',
			'..---':'2',
			'...--':'3',
			'....-':'4',
			'.....':'5',
			'-....':'6',
			'--...':'7',
			'---..':'8',
			'----.':'9'
		}
		b = ""
		n = string.split()
		for i in n:
			if i in code:
				b += code[i]
			else:
				b += "#"
		return b

	def tapCode(string):
		code = {
		    "A": ". .",
		    "B": ". ..",
		    "C": ". ...",
		    "D": ". ....",
		    "E": ". .....",
		    "F": ".. .",
		    "G": ".. ..",
		    "H": ".. ...",
		    "I": ".. ....",
		    "J": ".. .....",
		    "K": ". ...",
		    "L": "... .",
		    "M": "... ..",
		    "N": "... ...",
		    "O": "... ....",
		    "P": "... .....",
		    "Q": ".... .",
		    "R": ".... ..",
		    "S": ".... ...",
		    "T": ".... ....",
		    "U": ".... .....",
		    "V": "..... .",
		    "W": "..... ..",
		    "X": "..... ...",
		    "Y": "..... ....",
		    "Z": "..... .....",
		}
		b = ""
		n = string.split("/")
		for i in n:
			if i == "":
				pass
			elif i != "#" or i != " ":
				b += list(code.keys())[list(code.values()).index(i)]
			elif i == " ":
				b += " "
			else:
				b += "#"
		return b

	#numeric
	def binary(string):
		string = string.split(" ")
		ans = ""
		for i in string:
			ans += str(int(i, 2))
		return ans

	def octal(string):
		string = string.split(" ")
		ans = ""
		for i in string:
			ans += str(int(i, 8))
		return ans

	def hexadecimal(string):
		string = string.split(" ")
		ans = ""
		for i in string:
			ans += str(int(i, 16))
		return ans

	#encoding
	def base16(string):
		m = string.encode("ascii")
		a = base64.b16decode(m)
		c = a.decode("ascii")
		return c

	def base32(string):
		m = string.encode("ascii")
		a = base64.b32decode(m)
		c = a.decode("ascii")
		return c

	def base64(string):
		m = string.encode("ascii")
		a = base64.b64decode(m)
		c = a.decode("ascii")
		return c

	def base85(string):
		m = string.encode("ascii")
		a = base64.b85decode(m)
		c = a.decode("ascii")
		return c
#---</decryption>---#

==> pycrypt-cli-0.5.tar.gz: pycrypt-cli-0.5/pycryptcli/techniques.py <==
#modules
import base64
import hashlib

#---<encryption>---#
class encryption:
	#cipher
	def ascii(string):
	    c = ""
	    for i in string:
	        c = c + str(ord(i))
	        c += " "
	    return c[:-1]

	def caeserCipher(string, key):
		key = int(key)
		c = ""
		for i in range (len(string)):
			a = string[i]
			if ord(a) not in range(65,91) and ord(a) not in range (97,124):
				c += a
			elif a.isupper():
				c += chr((ord(a) + key - 65) % 26 + 65)
			else:
				c += chr((ord(a) + key - 97) % 26 + 97)
		return c

	def vigenereCipher(string, key):
	    c = ""
	    a = [ord(i) for i in (string)]
	    b = [ord(j) for j in (key)]
	    for x in range (len(string)):
	        d = (a[x] + b[x % len(key)]) % 26
	        if string[x].islower() == True:
	        	c = c + chr(97 + d)
	        else:
	        	c = c+ chr(65 + d)
	    return c

	def morseCode(string):
		code = {
			' ':'|',
			'a':'.-',
			'b':'-...',
			'c':'-.-.',
			'd':'-..',
			'e':'.',
			'f':'..-.',
			'g':'--.',
			'h':'....',
			'i':'..',
			'j':'.---',
			'k':'-.-',
			'l':'.-..',
			'm':'--',
			'n':'-.',
			'o':'---',
			'p':'.--.',
			'q':'--.-',
			'r':'.-.',
			's':'...',
			't':'-',
			'u':'..-',
			'v':'...-',
			'w':'.--',
			'x':'-..-',
			'y':'-.--',
			'z':'--..',
			'0':'-----',
			'1':'.----',
			'2':'..---',
			'3':'...--',
			'4':'....-',
			'5':'.....',
			'6':'-....',
			'7':'--...',
			'8':'---..',
			'9':'----.'
		}
		b = ""
		for i in string:
			if i.isalpha() == True:
				i = i.lower()
			if i in code:
				b += code[i]
			else:
				b += "#"
			b += " "
		return b[:-1]

	def tapCode(string):
		code = {
		    "A": ". .",
		    "B": ". ..",
		    "C": ". ...",
		    "D": ". ....",
		    "E": ". .....",
		    "F": ".. .",
		    "G": ".. ..",
		    "H": ".. ...",
		    "I": ".. ....",
		    "J": ".. .....",
		    "K": ". ...",
		    "L": "... .",
		    "M": "... ..",
		    "N": "... ...",
		    "O": "... ....",
		    "P": "... .....",
		    "Q": ".... .",
		    "R": ".... ..",
		    "S": ".... ...",
		    "T": ".... ....",
		    "U": ".... .....",
		    "V": "..... .",
		    "W": "..... ..",
		    "X": "..... ...",
		    "Y": "..... ....",
		    "Z": "..... .....",
		}
		c = ""
		string = string.upper()
		string = string.rstrip("\n")
		for i in string:
			if i in code:
				c += code[i] + "/"
			elif i == " ":
				c += " "
			else:
				c += "#"
		return c

	#numeric
	def binary(string):
		ans = ""
		for i in string:
			if i.isdigit() == False:
				ans += bin(int(ord(i)))[2:]
			else:
				ans += bin(int(i))[2:]
			ans += " "
		return ans[:-1]

	def octal(string):
	    ans = ""
	    for i in string:
	    	if i.isdigit() == False:
	    		ans += oct(int(ord(i)))[2:]
	    	else:
	    		ans += oct(int(i))[2:]
	    	ans += " "
	    return ans[:-1]

	def hexadecimal(string):
		ans = ""
		for i in string:
			if i.isdigit() == False:
				ans += hex(int(ord(i)))[2:]
			else:
				ans += hex(int(i))[2:]
			ans += " "
		return ans[:-1]

	#encoding
	def base16(string):
	    m = string.encode("ascii")
	    a = base64.b16encode(m)
	    c = a.decode("ascii")
	    return c

	def base32(string):
	    m = string.encode("ascii")
	    a = base64.b32encode(m)
	    c = a.decode("ascii")
	    return c

	def base64(string):
	    m = string.encode("ascii")
	    a = base64.b64encode(m)
	    c = a.decode("ascii")
	    return c

	def base85(string):
	    m = string.encode("ascii")
	    a = base64.b85encode(m)
	    c = a.decode("ascii")
	    return c

	#hash function
	def md5(string):
		n = string.encode()
		c = hashlib.md5(n).hexdigest()
		return c 

	def sha224(string):
		n = string.encode()
		c = hashlib.sha224(n).hexdigest()
		return c

	def sha256(string):
		n = string.encode()
		c = hashlib.sha256(n).hexdigest() 
		return c
	
	def sha384(string):
		n = string.encode()
		c = hashlib.sha384(n).hexdigest() 
		return c

	def sha512(string):
		n = string.encode()
		c = hashlib.sha512(n).hexdigest() 
		return c

	def sha3_256(string):
		n = string.encode()
		c = hashlib.sha3_256(n).hexdigest() 
		return c

	def sha3_512(string):
		n = string.encode()
		c = hashlib.sha3_512(n).hexdigest() 
		return c

	def blake2_256(string):
		n = string.encode()
		c = hashlib.blake2s(n).hexdigest() 
		return c

	def blake2_512(string):
		n = string.encode()
		c = hashlib.blake2b(n).hexdigest() 
		return c
#---</encryption>---#

#---<decryption>---#
class decryption:
	#cipher
	def ascii(string):
		n = string.split(" ")
		c = ""
		for i in n:
			c = c + str(chr(int(i)))
		return c

	def caeserCipher(string, key):
		key = int(key)
		c = ""
		for i in range (len(string)):
			a = string[i]
			if ord(a) not in range (65,91) and ord(a) not in range (97,124):
				c += a
			elif a.isupper():
				c += chr((ord(a) - key - 65) % 26 + 65)
			else:
				c += chr((ord(a) - key - 97) % 26 + 97)
		return c

	def vigenereCipher(string, key):
		c = ""
		a = [ord(i) for i in (string)]
		b = [ord(i) for i in (key)]
		for x in range (len(string)):
			d = (a[x] - b[x % len(key)]) % 26
			if string[x].islower() == True:
				c += chr(97 + d)
			else:
				c += chr(65 + d)
		return c

	def morseCode(string):
		code={
			'|':' ',
			'.-':'a',
			'-...':'b',
			'-.-.':'c',
			'-..':'d',
			'.':'e',
			'..-.':'f',
			'--.':'g',
			'....':'h',
			'..':'i',
			'.---':'j',
			'-.-':'k',
			'.-..':'l',
			'--':'m',
			'-.':'n',
			'---':'o',
			'.--.':'p',
			'--.-':'q',
			'.-.':'r',
			'...':'s',
			'-':'t',
			'..-':'u',
			'...-':'v',
			'.--':'w',
			'-..-':'x',
			'-.--':'y',
			'--..':'z',
			'-----':'0',
			'.----':'1',
			'..---':'2',
			'...--':'3',
			'....-':'4',
			'.....':'5',
			'-....':'6',
			'--...':'7',
			'---..':'8',
			'----.':'9'
		}
		b = ""
		n = string.split()
		for i in n:
			if i in code:
				b += code[i]
			else:
				b += "#"
		return b

	def tapCode(string):
		code = {
		    "A": ". .",
		    "B": ". ..",
		    "C": ". ...",
		    "D": ". ....",
		    "E": ". .....",
		    "F": ".. .",
		    "G": ".. ..",
		    "H": ".. ...",
		    "I": ".. ....",
		    "J": ".. .....",
		    "K": ". ...",
		    "L": "... .",
		    "M": "... ..",
		    "N": "... ...",
		    "O": "... ....",
		    "P": "... .....",
		    "Q": ".... .",
		    "R": ".... ..",
		    "S": ".... ...",
		    "T": ".... ....",
		    "U": ".... .....",
		    "V": "..... .",
		    "W": "..... ..",
		    "X": "..... ...",
		    "Y": "..... ....",
		    "Z": "..... .....",
		}
		b = ""
		n = string.split("/")
		for i in n:
			if i == "":
				pass
			elif i != "#" or i != " ":
				b += list(code.keys())[list(code.values()).index(i)]
			elif i == " ":
				b += " "
			else:
				b += "#"
		return b

	#numeric
	def binary(string):
		string = string.split(" ")
		ans = ""
		for i in string:
			ans += str(int(i, 2))
			ans += " "
		return ans[:-1]

	def octal(string):
		string = string.split(" ")
		ans = ""
		for i in string:
			ans += str(int(i, 8))
			ans += " "
		return ans[:-1]

	def hexadecimal(string):
		string = string.split(" ")
		ans = ""
		for i in string:
			ans += str(int(i, 16))
			ans += " "
		return ans[:-1]

	#encoding
	def base16(string):
		m = string.encode("ascii")
		a = base64.b16decode(m)
		c = a.decode("ascii")
		return c

	def base32(string):
		m = string.encode("ascii")
		a = base64.b32decode(m)
		c = a.decode("ascii")
		return c

	def base64(string):
		m = string.encode("ascii")
		a = base64.b64decode(m)
		c = a.decode("ascii")
		return c

	def base85(string):
		m = string.encode("ascii")
		a = base64.b85decode(m)
		c = a.decode("ascii")
		return c
#---</decryption>---#
